==> client-api-2.3.8.tgz: package/lib/fast-gui/api.js <==
/// <reference path="../../reference/cristalix.d.ts" />
import { ItemElement, RectangleElement, TextElement } from './elements';
import { overlayLegacy, runningTasks, lastScreenState } from "./fast-gui";
import { parentSizeX, parentSizeY } from "./index";
export var CENTER = { x: 0.5, y: 0.5 };
export var LEFT = { x: 0, y: 0.5 };
export var RIGHT = { x: 1, y: 0.5 };
export var TOP = { x: 0.5, y: 0 };
export var BOTTOM = { x: 0.5, y: 1 };
export var TOP_RIGHT = { x: 1, y: 0 };
export var TOP_LEFT = { x: 0, y: 0 };
export var BOTTOM_RIGHT = { x: 1, y: 1 };
export var BOTTOM_LEFT = { x: 0, y: 1 };
export function schedule(delay, action) {
    runningTasks.push({
        time: System.currentTimeMillis() + delay,
        action: action
    });
}
export function rect(data) {
    var element = new RectangleElement(data);
    element.cleanMatrices();
    return element;
}
export function text(data) {
    var element = new TextElement(data);
    element.cleanMatrices();
    return element;
}
export function item(data) {
    var element = new ItemElement(data);
    element.cleanMatrices();
    return element;
}
export function removeFromOverlay() {
    var elements = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        elements[_i] = arguments[_i];
    }
    for (var _a = 0, elements_1 = elements; _a < elements_1.length; _a++) {
        var element = elements_1[_a];
        var index = overlayLegacy.indexOf(element);
        overlayLegacy.splice(index, 1);
    }
}
export function addToOverlay() {
    var elements = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        elements[_i] = arguments[_i];
    }
    for (var _a = 0, elements_2 = elements; _a < elements_2.length; _a++) {
        var element = elements_2[_a];
        element.setProperty(parentSizeX, lastScreenState.screenWidth);
        element.setProperty(parentSizeY, lastScreenState.screenHeight);
    }
    overlayLegacy.push.apply(overlayLegacy, elements);
}

==> client-api-2.3.14.tgz: package/lib/fast-gui/api.js <==
/// <reference path="../../reference/cristalix.d.ts" />
import { ItemElement, RectangleElement, TextElement } from './elements';
import { overlayLegacy, runningTasks, lastScreenState } from "./fast-gui";
import { parentSizeX, parentSizeY } from "./index";
export var CENTER = { x: 0.5, y: 0.5 };
export var LEFT = { x: 0, y: 0.5 };
export var RIGHT = { x: 1, y: 0.5 };
export var TOP = { x: 0.5, y: 0 };
export var BOTTOM = { x: 0.5, y: 1 };
export var TOP_RIGHT = { x: 1, y: 0 };
export var TOP_LEFT = { x: 0, y: 0 };
export var BOTTOM_RIGHT = { x: 1, y: 1 };
export var BOTTOM_LEFT = { x: 0, y: 1 };
export function schedule(delay, action) {
    runningTasks.push({
        time: System.currentTimeMillis() + delay,
        action: action
    });
}
export function rect(data) {
    var element = new RectangleElement(data);
    // element.cleanMatrices();
    return element;
}
export function text(data) {
    var element = new TextElement(data);
    // element.cleanMatrices();
    return element;
}
export function item(data) {
    var element = new ItemElement(data);
    // element.cleanMatrices();
    return element;
}
export function removeFromOverlay() {
    var elements = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        elements[_i] = arguments[_i];
    }
    for (var _a = 0, elements_1 = elements; _a < elements_1.length; _a++) {
        var element = elements_1[_a];
        var index = overlayLegacy.indexOf(element);
        overlayLegacy.splice(index, 1);
    }
}
export function addToOverlay() {
    var elements = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        elements[_i] = arguments[_i];
    }
    for (var _a = 0, elements_2 = elements; _a < elements_2.length; _a++) {
        var element = elements_2[_a];
        element.setProperty(parentSizeX, lastScreenState.screenWidth);
        element.setProperty(parentSizeY, lastScreenState.screenHeight);
    }
    overlayLegacy.push.apply(overlayLegacy, elements);
}
